"""Packs group together related settings and configuration files.

This contains the following optional packs:

* :mod:`~ou_container_content.packs.mariadb`
* :mod:`~ou_container_content.packs.nbclassic`
* :mod:`~ou_container_content.packs.tutorial_server`
"""
from .nbclassic import apply_pack as nbclassic  # noqa
from .mariadb import apply_pack as mariadb  # noqa
from .tutorial_server import apply_pack as tutorial_server  # noqa



"""Core settings processing functionality.

The core functionality covers

* :mod:`~ou_container_content.core.content`
* :mod:`~ou_container_content.core.env`
* :mod:`~ou_container_content.core.scripts`
* :mod:`~ou_container_content.core.services`
* :mod:`~ou_container_content.core.web_apps`

The functionality provided by these is processed after any packs are processed.
"""
from .content import apply_core as content  # noqa
from .env import apply_core as env  # noqa
from .scripts import apply_core as scripts  # noqa
from .services import apply_core as services  # noqa
from .web_apps import apply_core as web_apps  # noqa



# ####################
# Server configuration
# ####################

c.ServerApp.quit_button = False
c.ServerApp.trust_xheaders = True
c.ServerApp.tornado_settings = {
    'headers': {
        'Content-Security-Policy': "frame-ancestors 'self' https://vce.computing.edgehill.ac.uk",
        'Access-Control-Allow-Origin': 'https://vce.computing.edgehill.ac.uk',
    }
}
{% if server.access_token %}
c.ServerApp.token = '{{ server.access_token }}'
{% endif %}
c.ServerApp.default_url = '{{ server.default_path }}'
c.ServerApp.quit_button = False
c.ServerApp.iopub_data_rate_limit = 10000000

# ##########################
# Server proxy configuration
# ##########################

{% if web_apps %}
c.ServerProxy.servers = {
    {% for app in web_apps %}
    '{{ app.path }}': {
        'command': {{ app.cmdline }},
        {% if app.port %}
        'port': app.port,
        {% endif %}
        {% if app.timeout %}
        'timeout': {{ app.timeout }},
        {% endif %}
        {% if app.absolute_url %}
        'absolute_url': True,
        {% endif %}
    },
    {% endfor %}
}
{% endif %}


# ##############################
# Classic notebook configuration
# ##############################

c.NotebookApp.quit_button = False
